skidge
======

A
`feature-rich <https://slidge.im/skidge/features.html>`_
`Skype <https://skype.com/>`_ to
`XMPP <https://xmpp.org/>`_ puppeteering
`gateway <https://xmpp.org/extensions/xep-0100.html>`_, based on
`slidge <https://slidge.im>`_ and
`skpy <https://skpy.t.allofti.me/>`_.

.. toctree::
   :maxdepth: 3

   readme
   features
   config
   user
   autoapi/index


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
